@@ -1,17 +1,8 @@
 /*
- * expr.h - Parse expression
- *
- * author       : Jeroen van der Heijden
- * email        : jeroen@transceptor.technology
- * copyright    : 2016, Transceptor Technology
- *
- * changes
- *  - initial version, 19-04-2016
- *
+ * expr.h - For parsing expressions.
  */
-#pragma once
-
-#include <inttypes.h>
+#ifndef EXPR_H_
+#define EXPR_H_
 
 #define EXPR_DIVISION_BY_ZERO -1
 #define EXPR_MODULO_BY_ZERO -2
@@ -28,5 +19,10 @@
  */
 #define EXPR_MAX_SIZE 512
 
+#include <inttypes.h>
+
 /* Returns 0 when result is successful set */
 int expr_parse(int64_t * result, const char * expr);
+
+
+#endif  /* EXPR_H_ */
