@@ -1,15 +1,8 @@
 /*
- * re.h - Helpers for regular expressions
- *
- * author       : Jeroen van der Heijden
- * email        : jeroen@transceptor.technology
- * copyright    : 2016, Transceptor Technology
- *
- * changes
- *  - initial version, 04-08-2016
- *
+ * re.h - Helpers for regular expressions.
  */
-#pragma once
+#ifndef SIRIDB_RE_H_
+#define SIRIDB_RE_H_
 
 #define PCRE2_CODE_UNIT_WIDTH 8
 
@@ -22,3 +15,6 @@ int siridb_re_compile(
         const char * source,
         size_t len,
         char * err_msg);
+
+
+#endif  /* SIRIDB_RE_H_ */
