@@ -18,6 +18,7 @@
 #include <xpath/xpath.h>
 #include <owcrypt/owcrypt.h>
 #include <siri/db/access.h>
+#include <base64/base64.h>
 
 
 #ifndef __APPLE__
@@ -194,7 +195,7 @@ int siridb_users_add_user(
 }
 
 /*
- * Returns NULL when the user is not found of when the given password is
+ * Returns NULL when the user is not found or when the given password is
  * incorrect. When *password is NULL the password will NOT be checked and
  * the user will be returned when found.
  */
@@ -249,6 +250,33 @@ siridb_user_t * siridb_users_get_user(
     return NULL;
 }
 
+siridb_user_t * siridb_users_get_user_from_basic(
+        siridb_t * siridb,
+        const char * data,
+        size_t n)
+{
+    size_t size, nn, end;
+    char * b64 = base64_decode(data, n, &size);
+    siridb_user_t * user = NULL;
+
+    for (nn = 0, end = size; nn < end; ++nn)
+    {
+        if (b64[nn] == ':')
+        {
+            b64[nn] = '\0';
+
+            if (++nn > end)
+                break;
+
+            user = siridb_users_get_user(siridb, b64, b64 + nn);
+            break;
+        }
+    }
+
+    free(b64);
+    return user;
+}
+
 /*
  * We get and remove the user in one code block so we do not need a dropped
  * flag on the user object.
